@@ -164,6 +164,10 @@ class Pipfile(object):
         # type: () -> Union[plette.pipfiles.Pipfile, PipfileLoader]
         return self.projectfile.model
 
+    @property
+    def root(self):
+        return self.path.parent
+
     @property
     def extended_keys(self):
         return [
